@@ -41,7 +41,7 @@ Simon (G7RZU) <simon@gb7fr.org.uk>
 
 use vars qw($VERSION);
 #Define version
-$VERSION = '0.3';
+$VERSION = '0.5';
 
 =head1 METHODS
 
@@ -119,6 +119,19 @@ sub _json_rubric_content {
     return($json);
 };
 
+=head2 json_response
+
+    Returns a hash ref to the last JSON response or undef if there is none
+    
+    $jsonhashref = $jsonobj->json_response;
+
+=cut
+
+sub json_response {
+    my($self) = shift;
+    return($self->{_JSONRESPONSEREF});
+};
+
 =head2 send_individual_call
 
 Send a call to a single callsign 
@@ -127,7 +140,6 @@ $ret = $dapnetobj->send_individual_call(<text>,<destination callsign>,<transmitt
 
 Returns 0 on sucess or the HTTP error string on error. 
 
-
 =cut
 
 sub send_individual_call {
@@ -136,7 +148,7 @@ sub send_individual_call {
     my($text,$to,$txgroup,$emergency) = @_;
     
     my($ua) = LWP::UserAgent->new;
-    my($jsonobj);
+    my($jsonresobj) = JSON->new;
     my($i) = 1;
     my($json);
     
@@ -144,7 +156,7 @@ sub send_individual_call {
         my($json) = $self->_json_individual_call($self->{CALLSIGN}.':'.$text,$to,$txgroup,$emergency);
         my($req) = $self->_build_request($json,'calls');    
         my($res) = $ua->request($req);
-        warn($res->status_line);
+        $self->{_JSONRESPONSEREF} = $jsonresobj->decode($res->decoded_content);
         if (!$res->is_success) {
             return($res->status_line);
         };
@@ -157,7 +169,7 @@ sub send_individual_call {
             };
             my($req) = $self->_build_request($json);    
            my($res) = $ua->request($req);
-           warn($res->status_line);
+           $self->{_JSONRESPONSEREF} = $jsonresobj->decode($res->decoded_content);
            if (!$res->is_success) {
                return($res->status_line);
            };
@@ -185,9 +197,8 @@ Returns 0 on sucess or the HTTP error string on error.
 sub send_rubric_content {
    my $self = shift;
     my($text,$rubric,$number) = @_;
-    
+    my($jsonresobj) = JSON->new;
     my($ua) = LWP::UserAgent->new;
-    my($jsonobj);
     my($i) = 1;
     my($json);
     
@@ -195,7 +206,7 @@ sub send_rubric_content {
         my($json) = $self->_json_rubric_content($self->{CALLSIGN}.':'.$text,$rubric,$number);
         my($req) = $self->_build_request($json,'news');    
         my($res) = $ua->request($req);
-        warn($res->status_line);
+        $self->{_JSONRESPONSEREF} = $jsonresobj->decode($res->decoded_content);
         if (!$res->is_success) {
             return($res->status_line);
         };
@@ -207,9 +218,9 @@ sub send_rubric_content {
                 $json = $self->_json_rubrik_content($self->{CALLSIGN}.':'.'...'.$substr,$rubric,$number);
             };
             my($req) = $self->_build_request($json);    
-           my($res) = $ua->request($req);
-           warn($res->status_line);
-           if (!$res->is_success) {
+            my($res) = $ua->request($req);
+            $self->{_JSONRESPONSEREF} = $jsonresobj->decode($res->decoded_content);
+            if (!$res->is_success) {
                return($res->status_line);
            };
             $i++;
